@@ -14,6 +14,7 @@ from aikido_zen.helpers.logging import logger
 from .wsgi import set_wsgi_attributes_on_context
 from .asgi import set_asgi_attributes_on_context
 from .extract_route_params import extract_route_params
+from ..helpers.headers import Headers
 
 UINPUT_SOURCES = ["body", "cookies", "query", "headers", "xml", "route_params"]
 current_context = contextvars.ContextVar("current_context", default=None)
@@ -48,11 +49,12 @@ class Context:
         self.xml = {}
         self.outgoing_req_redirects = []
         self.set_body(body)
+        self.headers: Headers = Headers()
+        self.cookies = dict()
+        self.query = dict()
 
         # Parse WSGI/ASGI/... request :
-        self.cookies = self.method = self.remote_address = self.query = self.headers = (
-            self.url
-        ) = None
+        self.method = self.remote_address = self.url = None
         if source in WSGI_SOURCES:
             set_wsgi_attributes_on_context(self, req)
         elif source in ASGI_SOURCES:
@@ -98,22 +100,26 @@ class Context:
         current_context.set(self)
 
     def set_body(self, body):
+        try:
+            self.set_body_internal(body)
+        except Exception as e:
+            logger.debug("Exception occurred whilst setting body: %s", e)
+
+    def set_body_internal(self, body):
         """Sets the body and checks if it's possibly JSON"""
         self.body = body
         if isinstance(self.body, (str, bytes)) and len(body) == 0:
             # Make sure that empty bodies like b"" don't get sent.
             self.body = None
+        if isinstance(self.body, bytes):
+            self.body = self.body.decode("utf-8")  # Decode byte input to string.
         if not isinstance(self.body, str):
             return
-        if self.body.strip()[0] in ["{", "["]:
+        if self.body.strip()[0] in ["{", "[", '"']:
             # Might be JSON, but might not have been parsed correctly by server because of wrong headers
-            try:
-                # Check if body is JSON :
-                parsed_body = json.loads(self.body)
-                if parsed_body:
-                    self.body = parsed_body
-            except JSONDecodeError:
-                pass
+            parsed_body = json.loads(self.body)
+            if parsed_body:
+                self.body = parsed_body
 
     def get_route_metadata(self):
         """Returns a route_metadata object"""
@@ -122,3 +128,6 @@ class Context:
             "route": self.route,
             "url": self.url,
         }
+
+    def get_user_agent(self):
+        return self.headers.get_header("USER_AGENT")
