@@ -3,8 +3,9 @@ Users file
 """
 
 from aikido_zen.helpers.logging import logger
-from aikido_zen.background_process import get_comms
 from . import get_current_context
+import aikido_zen.thread.thread_cache as thread_cache
+import aikido_zen.helpers.get_current_unixtime_ms as t
 
 
 def set_user(user):
@@ -20,12 +21,24 @@ def set_user(user):
     if not context:
         logger.debug("No context set, returning")
         return
+    if context.executed_middleware is True:
+        # Middleware to rate-limit/check for users ran already. Could be misconfiguration.
+        logger.warning(
+            "set_user(...) must be called before the Zen middleware is executed."
+        )
+
     validated_user["lastIpAddress"] = context.remote_address
     context.user = validated_user
 
     # Send validated_user object to background process :
-    if get_comms():
-        get_comms().send_data_to_bg_process("USER", validated_user)
+    cache = thread_cache.get_cache()
+    if cache:
+        cache.users.add_user(
+            user_id=validated_user["id"],
+            user_name=validated_user["name"],
+            user_ip=validated_user["lastIpAddress"],
+            current_time=t.get_unixtime_ms(),
+        )
 
 
 def validate_user(user):
