@@ -3,6 +3,7 @@ from unittest.mock import patch, MagicMock
 from aikido_zen.background_process.routes import Routes
 from .thread_cache import ThreadCache, get_cache
 from .. import set_user
+from ..background_process.packages import PackagesStore
 from ..background_process.service_config import ServiceConfig
 from ..context import current_context, Context
 from aikido_zen.helpers.iplist import IPList
@@ -41,6 +42,7 @@ def test_initialization(thread_cache: ThreadCache):
     assert thread_cache.config.blocked_uids == set()
     assert thread_cache.stats.get_record()["requests"] == {
         "total": 0,
+        "rateLimited": 0,
         "aborted": 0,
         "attacksDetected": {"total": 0, "blocked": 0},
     }
@@ -76,6 +78,7 @@ def test_reset(thread_cache: ThreadCache):
     assert thread_cache.config.blocked_uids == set()
     assert thread_cache.stats.get_record()["requests"] == {
         "total": 0,
+        "rateLimited": 0,
         "aborted": 0,
         "attacksDetected": {"total": 0, "blocked": 0},
     }
@@ -99,6 +102,7 @@ def test_renew_with_no_comms(thread_cache: ThreadCache):
         assert thread_cache.config.blocked_uids == set()
         assert thread_cache.stats.get_record()["requests"] == {
             "total": 0,
+            "rateLimited": 0,
             "aborted": 0,
             "attacksDetected": {"total": 0, "blocked": 0},
         }
@@ -252,9 +256,19 @@ def test_renew_called_with_correct_args(mock_get_comms, thread_cache: ThreadCach
     with patch(
         "aikido_zen.helpers.get_current_unixtime_ms.get_unixtime_ms", return_value=-1
     ):
+        PackagesStore.add_package("test-package-4", "4.3.0")
+        PackagesStore.clear()
+        PackagesStore.add_package("test-package-1", "4.3.0")
         thread_cache.renew()
 
     assert thread_cache.ai_stats.empty()
+    assert PackagesStore.get_package("test-package-1") == {
+        "cleared": True,
+        "name": "test-package-1",
+        "requiredAt": -1,
+        "version": "4.3.0",
+    }
+    assert PackagesStore.export() == []
 
     # Assert that send_data_to_bg_process was called with the correct arguments
     mock_comms.send_data_to_bg_process.assert_called_once_with(
@@ -274,6 +288,7 @@ def test_renew_called_with_correct_args(mock_get_comms, thread_cache: ThreadCach
                 "endedAt": -1,
                 "requests": {
                     "total": 2,
+                    "rateLimited": 0,
                     "aborted": 0,
                     "attacksDetected": {"blocked": 1, "total": 3},
                 },
@@ -313,6 +328,14 @@ def test_renew_called_with_correct_args(mock_get_comms, thread_cache: ThreadCach
             "middleware_installed": False,
             "hostnames": [],
             "users": [],
+            "packages": [
+                {
+                    "name": "test-package-1",
+                    "version": "4.3.0",
+                    "requiredAt": -1,
+                    "cleared": False,
+                }
+            ],
         },
         receive=True,
     )
@@ -350,6 +373,7 @@ def test_sync_data_for_users(mock_get_comms, thread_cache: ThreadCache):
                 "endedAt": -1,
                 "requests": {
                     "total": 1,
+                    "rateLimited": 0,
                     "aborted": 0,
                     "attacksDetected": {"total": 0, "blocked": 0},
                 },
@@ -358,6 +382,7 @@ def test_sync_data_for_users(mock_get_comms, thread_cache: ThreadCache):
             "middleware_installed": False,
             "hostnames": [],
             "ai_stats": [],
+            "packages": [],
             "users": [
                 {
                     "id": "123",
@@ -401,6 +426,7 @@ def test_renew_called_with_empty_routes(mock_get_comms, thread_cache: ThreadCach
                 "endedAt": -1,
                 "requests": {
                     "total": 0,
+                    "rateLimited": 0,
                     "aborted": 0,
                     "attacksDetected": {"total": 0, "blocked": 0},
                 },
@@ -410,6 +436,7 @@ def test_renew_called_with_empty_routes(mock_get_comms, thread_cache: ThreadCach
             "hostnames": [],
             "users": [],
             "ai_stats": [],
+            "packages": [],
         },
         receive=True,
     )
@@ -440,6 +467,7 @@ def test_renew_called_with_no_requests(mock_get_comms, thread_cache: ThreadCache
                 "endedAt": -1,
                 "requests": {
                     "total": 0,
+                    "rateLimited": 0,
                     "aborted": 0,
                     "attacksDetected": {"total": 0, "blocked": 0},
                 },
@@ -449,6 +477,7 @@ def test_renew_called_with_no_requests(mock_get_comms, thread_cache: ThreadCache
             "hostnames": [],
             "users": [],
             "ai_stats": [],
+            "packages": [],
         },
         receive=True,
     )
